@@ -41,8 +41,8 @@ class ResultSet(object):
         return ([int((i - datetime.datetime(1970, 1, 1)).total_seconds()) \
                 for i in self.timeseries], self.values)
 
-    def plotd(self):
-        """plots graph of values"""
+    def chart(self):
+        """plots chart of values"""
         import matplotlib.pyplot as plt
         import matplotlib.dates as mdates
         fig = plt.figure()
@@ -80,10 +80,14 @@ class ResultSet(object):
     def summary(self):
         """prints summary"""
         #todo: should get rid of print statements
-        print "Year 1 Annual _output: %s kWh" % self.annual_output
+        print "Year 1 Annual output: %s kWh" % self.annual_output
         print "Year 1 Daily Average: %s kWh" % self.daily_ave
         print "Inverter hours clipping: %s" % self.clipping_hours
 
+    def __repr__(self):
+        return "Total output: %s" % \
+                round(sum(self.values),1)
+
 def load_system(filename):
     """Load a system from a json file"""
     try:
@@ -112,8 +116,7 @@ def json_system(json_description):
                 parallel = i["parallel"]
             else:
                 parallel = 1
-            shape = [{"series":i["series"],
-                    "parallel":parallel}]
+            shape = [{"series":i["series"], "parallel":parallel}]
         else:
             shape = [{'series':1}]
 
@@ -136,7 +139,8 @@ def json_system(json_description):
         json_shape += [block] * scale
     plant = System(json_shape)
     if 'station_class' in json_description:
-        plant.set_zipcode(json_description["zipcode"], json_description['station_class'])
+        plant.set_zipcode(json_description["zipcode"], \
+                json_description['station_class'])
     else:
         plant.set_zipcode(json_description["zipcode"])
     if "address" in json_description:
@@ -163,7 +167,7 @@ def json_system(json_description):
         plant.tilt = orientations[0]["tilt"]
         plant.azimuth = orientations[0]["azimuth"]
     if 'shade' in json_description:
-        plant.hourly_shade = pathfinder.hourly(json_description['shade'])
+        plant.hourly_shade = pathfinder.Hourly(json_description['shade'])
 
     plant.phase = json_description["phase"]
     plant.voltage = json_description["voltage"]
@@ -178,7 +182,7 @@ def _calc(record):
             horizon, properties['tilt'], properties['azimuth'], \
             properties['model_name'])
     year = 2000
-    timestamp = tmy3.normalizeDate(record['datetime'], year)
+    timestamp = tmy3.normalize_date(record['datetime'], year)
     return timestamp, insolation, record
 
 class System(object):
@@ -194,7 +198,7 @@ class System(object):
         self.system_name = ""
         self.clip = 0
 
-    def set_zipcode(self, zipcode, station_class = 3):
+    def set_zipcode(self, zipcode, station_class=3):
         """update zipcode"""
         self.zipcode = zipcode
         self.place = geo.zip_coordinates(self.zipcode)
@@ -363,10 +367,10 @@ class System(object):
             weather_data = forecast.data(self.place)['currently']
 
         if model == 'CC':
-            record = irradiation.blave(timestamp, self.place, self.tilt,
+            record = irradiation.blave(timestamp, self.place, self.tilt, \
                     self.azimuth, cloudCover=weather_data['cloudCover'])
         else:
-            record = irradiation.blave(timestamp, self.place, self.tilt,
+            record = irradiation.blave(timestamp, self.place, self.tilt, \
                     self.azimuth)
 
         irradiance = irradiation.irradiation(record, self.place, None,\
@@ -399,7 +403,7 @@ class System(object):
             iteration += 1
             if iteration > 25:
                 raise Exception('too many iterations')
-        solar_az, solar_alt = irradiation.ephemSun(self.place, timestamp)
+        solar_az, solar_alt = irradiation.ephem_sun(self.place, timestamp)
         irrRec = irradiation.irrGuess(timestamp, girr, solar_alt, solar_az,\
                 self.tilt, self.azimuth)
         irrRec['girr'] = round(girr, 0)
@@ -407,13 +411,15 @@ class System(object):
 
     def forecast_output(self, daylightSavings=False, source=None, hours=24):
         """forecast output of system"""
+        #todo: model and forecast should use consistant units; Wh or KWh
         #default is forecast with solpy.blave
         #this is ugly code... sorry
+        #todo: refactor
         d = datetime.date.today()
         endTimeUTC = datetime.datetime(d.year, d.month, d.day)\
                 + datetime.timedelta(hours=hours-self.tz)
         if source == 'noaa':
-            wseries = noaa.herpDerpInterp(self.place)
+            wseries = noaa.herp_derp_interp(self.place)
             ts = []
             irr = []
             for i in wseries:
@@ -472,16 +478,16 @@ class System(object):
         else:
             #blave
             stime = datetime.datetime.today().timetuple()
-            tzOff = datetime.timedelta(hours=self.tz)
+            tz_off = datetime.timedelta(hours=self.tz)
             if daylightSavings:
-                tzOff += datetime.timedelta(hours=1)
+                tz_off += datetime.timedelta(hours=1)
             else:
-                tzOff += datetime.timedelta(hours=0)
-            initTime = datetime.datetime(stime[0], stime[1], stime[2]) - tzOff
+                tz_off += datetime.timedelta(hours=0)
+            initTime = datetime.datetime(stime[0], stime[1], stime[2]) - tz_off
             timeseries = []
             values = []
             ts = initTime
-            while ts < datetime.datetime.now()-tzOff:
+            while ts < datetime.datetime.now()-tz_off:
                 ts += datetime.timedelta(minutes=5)
                 currentPower = self.now(ts)
                 values.append(currentPower)
